#! /usr/bin/env python
# encoding: utf-8
# WARNING! Do not edit! https://waf.io/book/index.html#_obtaining_the_waf_file

from.import generic
import os.path as osp
from waflib.Utils import to_list
mydir=osp.dirname(__file__)
package_descriptions=dict(ZLib=dict(incs=['zlib.h'],libs=['z']),FFTW=dict(incs=['fftw3.h'],libs=['fftw3f'],pcname='fftw3f'),FFTWThreads=dict(libs=['fftw3f_threads'],pcname='fftw3f',mandatory=False),JsonCpp=dict(incs=["json/json.h"],libs=['jsoncpp']),Eigen=dict(incs=["Eigen/Dense"],pcname='eigen3'),Jsonnet=dict(incs=["libjsonnet++.h"],libs=['jsonnet++','jsonnet']),TBB=dict(incs=["tbb/parallel_for.h"],libs=['tbb'],mandatory=False),HDF5=dict(incs=["hdf5.h"],libs=['hdf5'],mandatory=False),H5CPP=dict(incs=["h5cpp/all"],mandatory=False),)
def options(opt):
	opt.load('boost')
	opt.load('smplpkgs')
	opt.load('rootsys')
	opt.load('cuda')
	for name in package_descriptions:
		generic._options(opt,name)
	opt.add_option('--build-debug',default='-O2 -ggdb3',help="Build with debug symbols")
def find_submodules(ctx):
	sms=list()
	for wb in ctx.path.ant_glob("**/wscript_build"):
		sms.append(wb.parent.name)
	sms.sort()
	return sms
def configure(cfg):
	print('Compile options: %s'%cfg.options.build_debug)
	cfg.load('boost')
	cfg.load('smplpkgs')
	for name,args in package_descriptions.items():
		generic._configure(cfg,name,**args)
	if getattr(cfg.options,"with_cuda",False)is False:
		print("sans CUDA")
	else:
		cfg.load('cuda')
	if getattr(cfg.options,"with_root",False)is False:
		print("sans ROOT")
	else:
		cfg.load('rootsys')
	cfg.check_boost(lib='system filesystem graph thread program_options iostreams regex')
	cfg.check(header_name="dlfcn.h",uselib_store='DYNAMO',lib=['dl'],mandatory=True)
	cfg.check(features='cxx cxxprogram',lib=['pthread'],uselib_store='PTHREAD')
	cfg.env.CXXFLAGS+=to_list(cfg.options.build_debug)
	cfg.env.CXXFLAGS+=['-DEIGEN_FFTW_DEFAULT=1']
	cfg.env.LIB+=['z']
	submodules=find_submodules(cfg)
	if'BOOST_PIPELINE=1'not in cfg.env.DEFINES and'dfp'in submodules:
		print('Removing submodule "dfp" due to lack of external')
		submodules.remove('dfp')
	for pkg,ext in[("root","ROOTSYS"),("tbb","TBB"),("tbb","FFTWTHREADS_LIB"),("cuda","CUDA"),("hio","H5CPP_ALL"),]:
		exts=to_list(ext)
		for ext in exts:
			have='HAVE_'+ext
			if have in cfg.env or have in cfg.env.define_key:
				continue
			if pkg in submodules:
				print('Removing package "%s" due to lack of external dependency "%s"'%(pkg,ext))
				submodules.remove(pkg)
	cfg.env.SUBDIRS=submodules
	print('Configured for submodules: %s'%(', '.join(submodules),))
	cfg.write_config_header('config.h')
def build(bld):
	subdirs=bld.env.SUBDIRS
	print('Building: %s'%(', '.join(subdirs),))
	bld.recurse(subdirs)
